@@ -59,7 +59,7 @@ setup_logo(GtkAboutDialog * dialog)
 {
 	GtkWidget * image;
 	
-	image=gtk_image_new_from_file(ARDATADIR "icons/ACE.png");
+	image=gtk_image_new_from_file(ARDATADIR "/icons/ACE_32.png");
 	gtk_widget_show(image);
 	gtk_about_dialog_set_logo(dialog, 
 		gtk_image_get_pixbuf(GTK_IMAGE(image)));
