@@ -147,21 +147,26 @@ gsh_handle_add_arguments(GSH * gsh, const gint argc, const gchar **argv,
 	case 'A': /* Add an internally updated applet.  */
 		handle_applet_arguments(gsh, argc, argv, counter);
 		break;
-	case 'b':
+
+	case 'b': /* Add a horizontal pane between previous widgets
+		     and following widgets.  */
 		GSH_COUNT(argc, counter);
 		gsh_setup_hpaned(gsh, argv[*counter]);
 		break;
 
-	case 'C':
+	case 'C': /* Add a command execution widget.  This is primarily
+		     for systems failing to support VTE.  */
 		add_command_shell(gsh, NULL);
 		break;
 
-	case 'c':
+	case 'c': /* Add a widget with value initialized by execution
+		     of command, specified by option argument.  */
 		handle_commanded_add_arguments(gsh, argc, argv, counter);
 		break;
 
 	case 'e':
 		GSH_COUNT(argc, counter);
+		GSH_SET(GSH_APP_MODE);
 		gsh_text_editor(gsh, argv[*counter]);
 		break;
 
@@ -188,6 +193,17 @@ gsh_handle_add_arguments(GSH * gsh, const gint argc, const gchar **argv,
 		ADD_PIPED_GENERIC(gsh, add_piped_label);
 		break;
 
+	case 'Q':
+	{
+		GSHQuickStart * quickstart;
+		quickstart=ARNEW(gsh, GSHQuickStart);
+		GSH_COUNT(argc, counter);
+		$(quickstart, add, gsh, argv[*counter], argv[(*counter)+1]);
+		GSH_COUNT(argc, counter);
+		$(gsh, manage, quickstart->__column);
+	}
+		break;
+
 	case 'r': /* Force creation of a new row.  */
 		$(gsh->rows, new);
 		break;
