@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2006 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -26,9 +26,9 @@
 #include "gtkshell.h"
 
 void
-     gsh_parse_arguments(struct GSH * gsh, int argc, char **argv);
+gsh_parse_arguments(GSH * gsh, const gint argc, const gchar **argv);
 
 void
-     gsh_check_row(struct GSH * gsh);
+gsh_check_row(GSH * gsh);
 
 #endif
