@@ -39,4 +39,7 @@ gsh_add_button(struct GSH * gsh, const gchar * string);
 	{ "Close", GTK_STOCK_CLOSE }\
 }
 
+gboolean
+gsh_check_command_exists(GSH * gsh, const gchar * command);
+
 #endif
