@@ -101,6 +101,10 @@ test_special_command(struct GSHCBData * cb)
 	{
 		terminal_feed((gchar *)command, gsh->terminal->widget);
 	}
+	else if(MATCH("About__"))
+	{
+		antiright_system("gtkshell -da &");
+	}
 	else 
 	{
 		/* Test other special command(s).  */
