@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2006 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -23,16 +23,26 @@
 #ifndef GSH_CALLBACKS_H
 #define GSH_CALLBACKS_H
 
-struct GSH_CBData
+struct GSHCBData
 {
 	struct GSH *gsh;
 	gpointer data;
+	void (*delete)(struct GSHCBData *);
+	void (*system)(GtkWidget *, gpointer);
+	void (*entry)(GtkWidget *, gpointer);
 };
 
-void
-     system_cb(GtkWidget *widget, gpointer data);
+struct GSHCBData *
+gsh_new_GSHCBData(struct GSH * gsh, gpointer data);
+
+#define GSH_TEST_EXIT(gsh_arg)\
+{\
+	struct GSH * gsh = gsh_arg;\
+	if (GSH_FLAG(GSH_CBEXIT))\
+		gtk_main_quit();\
+}
 
 void
-     entry_cb(GtkWidget *widget, gpointer data);
+gsh_send_signal(GtkWidget * widget, const gchar * signal_name);
 
-#endif
+#endif /* not GSH_CALLBACKS_H */
