@@ -53,11 +53,6 @@ update_clock(const gchar * command, gpointer clock_pointer)
 	gtk_label_set_text(GTK_LABEL((GtkWidget *)clock_pointer), time_string);
 }
 
-#define GSH_SET_CLOCK_COLORS(clock, event_box)\
-	gsh_widget_set_color(event_box, "#223", FALSE);\
-	gsh_widget_set_color(clock, "#dde", TRUE);
-	
-
 static GtkWidget *
 setup_containers(GtkWidget * clock)
 {
@@ -69,10 +64,13 @@ setup_containers(GtkWidget * clock)
 		GtkWidget * event_box;
 
 		gtk_widget_show(event_box=gtk_event_box_new());
+		/* Setup containers.  */
 		GSHCA(frame, event_box);
-		GSH_SET_CLOCK_COLORS(clock, event_box);
 		GSHCA(event_box, clock);
+		/* Set clock colors.  */
+		gsh_widget_set_color(event_box, "#223", FALSE);
 	}
+	gsh_widget_set_color(clock, "#dde", TRUE);
 
 	return frame;
 }
