@@ -20,23 +20,26 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef GSH_FILE_DIALOG
-#define GSH_FILE_DIALOG
+#ifndef GSH_FILE_DIALOG_H
+#define GSH_FILE_DIALOG_H
 
-void
-gsh_file_dialog(struct GSH * gsh, 
-		GtkFileChooserAction action) __attribute__((noreturn));
+#define GSH_FILE_DIALOG(gsh, action)\
+	gsh_common_dialog_executioner(gsh,\
+		gtk_file_chooser_dialog_new("File Chooser",\
+		GTK_WINDOW(gsh->widgets.window), action, GTK_STOCK_CANCEL,\
+		GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL),\
+		gsh_file_dialog_submit);
 
 #define GSH_FILE_OPEN_DIALOG(gsh)\
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_OPEN)
+	GSH_FILE_DIALOG(gsh, GTK_FILE_CHOOSER_ACTION_OPEN)
 
 #define GSH_FILE_SAVE_DIALOG(gsh)\
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_SAVE)
+	GSH_FILE_DIALOG(gsh, GTK_FILE_CHOOSER_ACTION_SAVE)
 
 #define GSH_FOLDER_CREATE_DIALOG(gsh)\
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER)
+	GSH_FILE_DIALOG(gsh, GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER)
 
 #define GSH_FOLDER_OPEN_DIALOG(gsh)\
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+	GSH_FILE_DIALOG(gsh, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
-#endif /* !GSH_FILE_DIALOG */
+#endif /* !GSH_FILE_DIALOG_H */
