@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2006 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -22,34 +22,36 @@
 
 #include "gtkshell.h"
 
-/* gsh->geometry is freed after this, so only call once.  */
-void
-gsh_set_geometry(struct GSH * gsh)
-{
-	ARIFP(gsh->geometry)
-	{
-		gtk_window_parse_geometry(GTK_WINDOW(gsh->window),
-					  gsh->geometry);
-		free(gsh->geometry);
-	}
-}
 
 static gboolean
 gsh_check_geometry(struct GSH * gsh)
 {
-	if (!ARPBOOL(gsh->geometry) 
-	    && ((gsh->bflags & GSH_SCROLL) == GSH_SCROLL))
-		ar_asprintf(&gsh->geometry, "400x267");
+	/* Use a default geometry if the application has a scrolling window and
+	 * the geometry has not yet been specified.  */
+	if(GSH_FLAG(GSH_SCROLL) && !ARPBOOL(gsh->geometry))
+		gsh->geometry=g_strdup("400x267");
 
-	ARIFP(gsh->geometry)
-		return TRUE;
-	else
-		return FALSE;
+	/* Result used in test of whether or not to set geometry.  */
+	return ARPBOOL(gsh->geometry);
 }
 
+/* gsh->geometry is freed after this, so only call once.  */
 void
 gsh_check_and_set_geometry(struct GSH * gsh)
 {
+#ifdef DEBUG
+	ARPASSERT(gsh);
+#endif /* DEBUG */
 	if (gsh_check_geometry(gsh))
-		gsh_set_geometry(gsh);
+	{
+		/* Use GTK convenience function to set window geometry.  */
+		gtk_window_parse_geometry(GTK_WINDOW(gsh->widgets.window),
+					  gsh->geometry);
+		/* Free the geometry string pointer after use, so this function,
+		 * if called twice, will use a default geometry, not the user
+		 * specified one.  */
+		g_free(gsh->geometry);
+		/* Mark as unallocated.  */
+		gsh->geometry=NULL;
+	}
 }
