@@ -71,8 +71,7 @@ get_default_image(struct GSH * gsh, const gchar * name)
 	gchar * prefixed_name;
 	GtkWidget * image;
 
-	ar_asprintf(&prefixed_name, PREFIX "/share/ACE-desktop/icons/%s", 
-			name);
+	ar_asprintf(&prefixed_name, ARDATADIR "/icons/%s", name);
 	/* Determine whether to use the file name constructed in prefixed_name
 	 * or to use a stock icon (tried if the file does not exit).  */
 	image = g_file_test(prefixed_name, G_FILE_TEST_EXISTS)
@@ -80,6 +79,9 @@ get_default_image(struct GSH * gsh, const gchar * name)
 		: gtk_image_new_from_stock(name, gsh->icon_size);
 	g_free(prefixed_name);
 
+	if(!image)
+		image=gtk_image_new_from_stock("gtk-execute", gsh->icon_size);
+
 	return image;
 }
 
@@ -108,7 +110,9 @@ gsh_image_button(struct GSH * gsh, char *command, char *name)
 			set_button_image(gsh->widgets.button, image);
 		}
 		else
+		{
 			set_menu_item_image(gsh, image);
+		}
 	}
 }
 
