@@ -23,6 +23,9 @@
 #ifndef GSH_IMAGE_BUTTON_H
 #define GSH_IMAGE_BUTTON_H
 
+GtkWidget *
+gsh_get_image(GSH * gsh, const gchar * name);
+
 void
 gsh_image_button(struct GSH * gsh, char *command, char *name);
 
