@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2006 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -24,9 +24,12 @@
 #define GSH_LABEL_H
 
 GtkWidget *
-          gsh_add_label(struct GSH * gsh, char *text);
+gsh_add_label(struct GSH * gsh, const gchar *text);
 
 void
-     gsh_set_label(GtkWidget *label, char *text);
+gsh_new_label(struct GSH * gsh, const gchar *text);
+
+void
+gsh_set_label(GtkWidget *label, const gchar *text);
 
 #endif
