@@ -41,6 +41,8 @@
 #define GSH_FIRST_TERMINAL	GSHBIT(13)
 #define GSH_TERM_TRANSPARENT	GSHBIT(14)
 #define GSH_IN_SECONDARY_WIN	GSHBIT(15)
+#define GSH_ICON_SIZE_IS_CUSTOM GSHBIT(16)
+#define GSH_CHECK_COMMANDS	GSHBIT(17)
 
 typedef guint Bitmask;
 
