@@ -22,10 +22,6 @@
 
 #include "gtkshell.h"
 
-#ifdef LIBGC
-#include <gc.h>
-#endif /* LIBGC */
-
 static void
 setup_gui(struct GSH * gsh, const gint argc, const gchar ** argv)
 {
@@ -35,7 +31,7 @@ setup_gui(struct GSH * gsh, const gint argc, const gchar ** argv)
 }
 
 int
-main(int argc, char **argv)
+thread_main(int argc, char **argv)
 {
 	struct GSH * gsh;
 
@@ -56,3 +52,9 @@ main(int argc, char **argv)
 
 	return (EXIT_SUCCESS);
 }
+
+int
+main(int argc, char ** argv)
+{
+	return thread_main(argc, argv);
+}
