@@ -39,7 +39,9 @@ parse_special_and_noicon_items(GSH * gsh, gchar ** pair)
 {
 	/* Test if a separator should be created.  */
 	if(!strncmp(pair[0], "---", 3))
+	{
 		setup_separator_menu_item(gsh);
+	}
 	/* String does not contain \n.  */
 	else if(strncmp(pair[0], "\\n", 2))
 	{ /* Support continuation lines for menu specification.  */
@@ -58,7 +60,12 @@ menuitem_parse(struct GSH * gsh, gchar * string)
 	ARPASSERT(pair[0]);
 #endif /* DEBUG */
 	if(pair[1])
-		gsh_image_button(gsh, pair[0], pair[1]);
+	{
+		if(gsh_check_command_exists(gsh, pair[0]))
+		{
+			gsh_image_button(gsh, pair[0], pair[1]);
+		}
+	}
 	else
 		parse_special_and_noicon_items(gsh, pair);
 	g_strfreev(pair);
@@ -78,6 +85,9 @@ find_and_set_compound_label_widget(GtkWidget * label, const gchar * label_text)
 	GList * children;
 
 	children=gtk_container_get_children(GTK_CONTAINER(label));
+#ifdef DEBUG
+	ARPASSERT(children);
+#endif /* DEBUG */
 	g_list_foreach(children, set_submenu_label, (gchar *)label_text);
 	g_list_free(children);
 }
@@ -110,6 +120,24 @@ begin_submenu(GSH * gsh, GtkWidget ** submenus,
 	find_and_set_label_widget(label, tokens[++(*i)]);
 }
 
+static void
+parse_submenu_or_item_specification(GSH * gsh, gchar ** tokens, 
+	guint * submenu_count, GtkWidget ** submenus, 
+	const guint max_menus, guint * i)
+{
+	const gchar * submenu_open = "-->";
+	const gboolean start_submenu = (!strncmp(tokens[*i], 
+		submenu_open, 3) && *submenu_count < max_menus);
+
+	if(start_submenu)
+		GSH_SET(GSH_MENU_BUTTON);
+	/* Create the menu item.  */
+	menuitem_parse(gsh, tokens[*i]);
+	if(start_submenu)
+		begin_submenu(gsh, submenus, submenu_count, 
+			i, tokens);
+}
+
 static void
 perform_addition_for_each_item(struct GSH * gsh, gchar ** tokens)
 {
@@ -129,19 +157,8 @@ perform_addition_for_each_item(struct GSH * gsh, gchar ** tokens)
 				gsh->rows->v=submenus[--submenu_count];
 		}
 		else
-		{
-			const gchar * submenu_open = "-->";
-			const gboolean start_submenu = (!strncmp(tokens[i], 
-				submenu_open, 3) && submenu_count < max_menus);
-
-			if(start_submenu)
-				GSH_SET(GSH_MENU_BUTTON);
-			/* Create the menu item.  */
-			menuitem_parse(gsh, tokens[i]);
-			if(start_submenu)
-				begin_submenu(gsh, submenus, &submenu_count, 
-					&i, tokens);
-		}
+			parse_submenu_or_item_specification(gsh, tokens,
+				&submenu_count, submenus, max_menus, &i);
 	}
 }
 
@@ -182,21 +199,47 @@ add_menu_bar(struct GSH * gsh)
 	return GWA.menubar;
 }
 
+GSHMenuType
+gsh_is_menubar_item(const gchar * label)
+{
+
+	if(!strcmp(label, "File"))
+		return GMT_FILE;
+	else if(!strcmp(label, "Edit"))
+		return GMT_EDIT;
+	else if(!strcmp(label, "Tools"))
+		return GMT_TOOLS;
+	else if(!strcmp(label, "View"))
+		return GMT_VIEW;
+	else if(!strcmp(label, "Help"))
+		return GMT_HELP;
+	else return GMT_NONE;
+}
+
 static void
 test_for_main_app_menus(GSH * gsh, GtkWidget * menu, const gchar * label)
 {
 #define GSHMENUS GWA.menus
-
-	if(!strcmp(label, "File"))
+	switch(gsh_is_menubar_item(label))
+	{
+	case GMT_FILE:
 		GSHMENUS.file=menu;
-	else if(!strcmp(label, "Edit"))
+		break;
+	case GMT_EDIT:
 		GSHMENUS.edit=menu;
-	else if(!strcmp(label, "Tools"))
-		GSHMENUS.tools=menu;
-	else if(!strcmp(label, "View"))
+		break;
+	case GMT_VIEW:
 		GSHMENUS.view=menu;
-	else if(!strcmp(label, "Help"))
+		break;
+	case GMT_TOOLS:
+		GSHMENUS.tools=menu;
+		break;
+	case GMT_HELP:
 		GSHMENUS.help=menu;
+		break;
+	case GMT_NONE:
+		break;
+	}
 }
 
 static GtkWidget *
