@@ -24,6 +24,19 @@
 #ifndef GSH_MENU_H
 #define GSH_MENU_H
 
+typedef enum 
+{
+	GMT_NONE,
+	GMT_FILE,
+	GMT_EDIT,
+	GMT_TOOLS,
+	GMT_VIEW,
+	GMT_HELP
+} GSHMenuType;
+
+GSHMenuType
+gsh_is_menubar_item(const gchar * label);
+
 void
 gsh_menubutton_parse(struct GSH * gsh, gchar **tokens);
 
