@@ -61,5 +61,7 @@
 #include "form.h"
 #include "dialog.h"
 #include "swallow.h"
+#include "GSHWidget.h"
+#include "quickstart.h"
 
 #endif /* not GSH_MODULE_INCLUDES_H */
