@@ -21,11 +21,15 @@
 */
 
 #include "gtkshell.h"
+#include "undo.h"
+
+static void
+setup_undo(GSH * gsh);
 
 #define ADD_ENTRY(widget, str)\
 	gtk_combo_box_prepend_text(GTK_COMBO_BOX(widget), str)
 
-/* Some sample entries to use when history is not useful, such as a
+/* Some sample entries to use when history is not usefu, such as a
  * dialog presentation of this field, where the window displaying the
  * field closes on the first activation.  */
 static void
@@ -77,16 +81,12 @@ gsh_setup_command_entry(struct GSH * gsh, const gchar *command)
 	return entry;
 }
 
-#define SET_WRAP_MODE(text)\
-	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text), GTK_WRAP_WORD)
-
-#define SET_MONOSPACED_FONT(text)\
-	gsh_widget_set_font(text, NULL)
-
-#define SET_OPTIONS(text)\
-{\
-	SET_WRAP_MODE(text);\
-	SET_MONOSPACED_FONT(text);\
+static void
+set_options(GtkWidget * text_widget)
+{
+	gtk_text_view_set_wrap_mode(
+		GTK_TEXT_VIEW(text_widget), GTK_WRAP_WORD);
+	gsh_widget_set_font(text_widget, NULL);
 }
 
 
@@ -96,8 +96,7 @@ setup_text_scroller(GSH * gsh, GtkWidget * text)
 	GtkWidget * scroller;
 
 	GSH_SHOW_CREATE(scroller, scrolled_window, NULL, NULL);
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroller),
-		text);
+	gtk_container_add(GTK_CONTAINER(scroller), text);
 	$(gsh, manage, scroller);
 }
 
@@ -110,8 +109,9 @@ gsh_text_area(struct GSH * gsh)
 	ARPASSERT(gsh);
 #endif /* DEBUG */
 	gtk_widget_show(text=gsh->editor.widget=gtk_text_view_new());
-	SET_OPTIONS(text);
+	set_options(text);
 	setup_text_scroller(gsh, text);
+	setup_undo(gsh);
 
 	return text;
 }
@@ -143,6 +143,39 @@ gsh_text_area_set_text(GtkWidget * widget, const gchar * text)
 	return buffer;
 }
 
+static void
+setup_undo(GSH * gsh)
+{
+	GtkWidget * text_widget=gsh->editor.widget;
+	GtkWidget * redo_button;
+	GtkWidget * undo_button;
+	GtkWidget * destination;
+
+	/* The undo and redo names are swapped within undo.c somehow,
+	   so a hack is to simply rename the buttons.  */
+	gtk_widget_show(redo_button=gtk_button_new_from_stock("gtk-redo"));
+	gtk_widget_show(undo_button=gtk_button_new_from_stock("gtk-undo"));
+	if(gsh->widgets.app.toolbar)
+		destination=gsh->widgets.app.toolbar;
+	else
+	{
+		/* Set up a horizontal container 
+		   for undo and redo buttons.  */
+		GSH_SET(GSH_NO_EXPAND);
+		GSH_SHOW_CREATE(destination, hbox, TRUE, 0);
+		$(gsh, manage, destination);
+	}
+	GSHCA(destination, undo_button);
+	GSHCA(destination, redo_button);
+	undo_init(text_widget, undo_button, redo_button);
+	g_signal_connect_swapped(G_OBJECT(undo_button), "clicked", 
+		(GCallback)undo_undo,
+		gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_widget)));
+	g_signal_connect_swapped(G_OBJECT(redo_button), "clicked", 
+		(GCallback)undo_redo,
+		gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_widget)));
+}
+
 /* This is currently just a text file viewer.  */
 void
 gsh_text_editor(struct GSH * gsh, const gchar *filename)
