@@ -23,6 +23,34 @@
 #ifndef GSH_TEXT_H
 #define GSH_TEXT_H
 
+#include "GSHWidget.h"
+
+typedef struct GSHText
+{
+	GSHWidget * parent;
+
+	void (*delete)(struct GSHText *);
+	GtkWidget * __text_widget;
+} GSHText;
+
+typedef struct GSHTextArea
+{
+	GSHText * parent;
+
+	void (*delete)(struct GSHTextArea *);
+} GSHTextArea;
+
+typedef struct GSHTextEditor
+{
+	GSHTextArea * parent;
+
+	void (*delete)(struct GSHTextEditor *);
+	GtkWidget * __text_widget;
+} GSHTextEditor;
+
+GSHTextEditor *
+gsh_new_GSHTextEditor();
+
 GtkTextBuffer *
 gsh_text_area_set_text(GtkWidget * widget, const gchar * text);
 
