@@ -36,4 +36,10 @@ struct GSHUpdatedWidget *
 gsh_new_GSHUpdatedWidget(void (*function)(const gchar *, gpointer), 
 	const gchar * command, GtkWidget * widget);
 
+#define GSH_NEW_UPDATER_WITH_COMMAND(gsh, function, widget, command)\
+	$(gsh->update, add, ARNEW(gsh, GSHUpdatedWidget,\
+		&function, command, widget))
+#define GSH_NEW_UPDATER(gsh, function, widget)\
+	GSH_NEW_UPDATER_WITH_COMMAND(gsh, function, widget, NULL)
+
 #endif
