@@ -23,50 +23,32 @@
 #include "gtkshell.h"
 
 static void
-gsh_test_updating(struct GSH * gsh)
+add_updater(GSH * gsh, const gint argc, gint * counter, 
+	const gchar ** argv, void (*add_func)(GSH *, const gchar *))
 {
-	ARPASSERT(gsh);
-	if((gsh->bflags & GSH_UPDATING) != GSH_UPDATING)
-	{
-		gsh_start_updates(gsh);
-		gsh->bflags |= GSH_UPDATING;
-	}
-
+	GSH_COUNT(argc, counter);
+	add_func(gsh, argv[*counter]);
 }
 
-static void
-gsh_updater_argument_generic(struct GSH * gsh, int argc, int *counter)
-{
-	gsh_count(argc, counter);
-	gsh_test_updating(gsh);
-}
-
-static void
-add_updater(struct GSH * gsh, int argc, int * counter, char **argv,
-		   void (*add_func)(struct GSH *, const gchar *))
-{
-#ifdef DEBUG
-	ARBUG("add_updater()");
-#endif /* DEBUG */
-
-	(*add_func)(gsh, (const gchar *)argv[*counter+1]);
-	gsh_updater_argument_generic(gsh, argc, counter);
-}
+#define UADD(type) \
+	add_updater(gsh, argc, counter, argv, &gsh_add_updated_##type)
 
 void
-gsh_handle_updated_arguments(struct GSH * gsh, int argc,
-			     char **argv, int *counter)
+gsh_handle_updated_arguments(GSH * gsh, const gint argc,
+			     const gchar **argv, gint *counter)
 {
+#ifdef DEBUG
+	ARPASSERT(gsh);
+#endif /* DEBUG */
+
 	g_assert(strlen(argv[(*counter)]) > 2);
 	switch (argv[(*counter)][3])
 	{
 	case 'l':
-		add_updater(gsh, argc, counter, argv,
-			    &gsh_add_updated_label);
+		UADD(label);
 		break;
 	case 'p':
-		add_updater(gsh, argc, counter, argv,
-			    &gsh_add_updated_progress);
+		UADD(progress);
 		break;
 	}
 }
