@@ -27,13 +27,8 @@ gsh_update_progress(const gchar *command, gpointer widget)
 {
 	gchar *results;
 
-#ifdef DEBUG
-	ARPASSERT(command);
-	ARPASSERT(widget);
-#endif /* DEBUG */
-
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR((GtkWidget *) widget),
-		strtod(results=antiright_pipe_read((char*)command), NULL));
+		g_strtod(results=antiright_pipe_read(command), NULL));
 	g_free(results);
 }
 
@@ -42,12 +37,7 @@ gsh_add_updated_progress(struct GSH * gsh, const gchar *command)
 {
 	GtkWidget *progress;
 
-#ifdef DEBUG
-	ARPASSERT(gsh);
-	ARPASSERT(command);
-#endif /* DEBUG */
-	progress=gtk_progress_bar_new();
-	$(gsh, manage, progress);
-	$(gsh->update, add, ARNEW(gsh, GSHUpdatedWidget, 
-		&gsh_update_progress, command, progress));
+	$(gsh, manage, progress=gtk_progress_bar_new());
+	GSH_NEW_UPDATER_WITH_COMMAND(gsh, gsh_update_progress, 
+		progress, command);
 }
